connected

Function connected 

pub(crate) async fn connected(
    __arg0: State<Arc<InternalState>>,
) -> impl IntoResponse
Lists peers with immediate observation data from the network graph.

Returns only peers that have at least one edge with immediate QoS data, representing nodes the current node has direct transport observations for.