pub(crate) async fn probability(
__arg0: State<Arc<InternalState>>,
) -> impl IntoResponseExpand description
Gets the current minimum incoming ticket winning probability defined by the network.
pub(crate) async fn probability(
__arg0: State<Arc<InternalState>>,
) -> impl IntoResponseGets the current minimum incoming ticket winning probability defined by the network.